@@ -3,6 +3,7 @@
 import os
 from typing import *
 
+import deprecation
 from cognite.seismic._api.api import API
 from google.protobuf.struct_pb2 import Struct
 
@@ -31,6 +32,7 @@ if not os.getenv("READ_THE_DOCS"):
         LineBasedRectangle,
         PositionQuery,
         Wkt,
+        ExternalId,
     )
     from google.protobuf.empty_pb2 import Empty
 
@@ -260,6 +262,8 @@ class FileAPI(API):
         xline_offset: Optional[int] = None,
         cdp_x_offset: Optional[int] = None,
         cdp_y_offset: Optional[int] = None,
+        source_group_scalar_override: Optional[float] = None,
+        external_id: Optional[str] = None,
     ):
         """Register a file on a survey
 
@@ -275,6 +279,8 @@ class FileAPI(API):
             xline_offset: Byte offset of crossline number field in the trace headers. Defaults to 193 as per the SEG-Y rev1 specification
             cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers. Defaults to 181 as per the SEG-Y rev1 specification
             cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers. Defaults to 185 as per the SEG-Y rev1 specification
+            source_group_scalar_override: Multiplier for CDP-X and CDP-Y values, overrides scalar factor obtained from trace header
+            external_id: An optional external id for a file
 
         Returns:
              The response from the gRPC server with the id the file was registered on.
@@ -284,6 +290,10 @@ class FileAPI(API):
         xline_offset_wrapped = None if xline_offset == None else wrappers.Int32Value(value=xline_offset)
         cdp_x_offset_wrapped = None if cdp_x_offset == None else wrappers.Int32Value(value=cdp_x_offset)
         cdp_y_offset_wrapped = None if cdp_y_offset == None else wrappers.Int32Value(value=cdp_y_offset)
+        source_group_scalar_override = (
+            None if source_group_scalar_override == None else wrappers.FloatValue(value=source_group_scalar_override)
+        )
+        external_id = None if external_id == None else ExternalId(external_id=external_id)
         request = RegisterFileRequest(
             survey=survey,
             path=bucket,
@@ -295,6 +305,8 @@ class FileAPI(API):
             crossline_offset=xline_offset_wrapped,
             cdp_x_offset=cdp_x_offset_wrapped,
             cdp_y_offset=cdp_y_offset_wrapped,
+            source_group_scalar_override=source_group_scalar_override,
+            external_id=external_id,
         )
         return self.ingestion.RegisterFile(request, metadata=self.metadata)
 
@@ -324,6 +336,10 @@ class FileAPI(API):
                5: COMPUTE_GRID
 
                6: COMPUTE_TRACE_INDICES
+            storage_tier(str): Optional target storage tier. Leave blank to use the default storage tier. 
+                EARLY ACCESS: Tiered storage is available in preview for select clients. Tier names and configurations
+                are client specific and not further documented here.
+
         Returns:
             IngestFileResponse: a Job id that can be used to query for status of the ingestion job, and the file id.
         """
@@ -363,6 +379,8 @@ class FileAPI(API):
         xline_offset: Optional[int] = None,
         cdp_x_offset: Optional[int] = None,
         cdp_y_offset: Optional[int] = None,
+        source_group_scalar_override: Optional[float] = None,
+        external_id: Optional[str] = None,
     ):
         """Edit a file by either its id or name.
 
@@ -377,6 +395,8 @@ class FileAPI(API):
             xline_offset: Byte offset of crossline number field in the trace headers.
             cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers.
             cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers.
+            source_group_scalar_override: Multiplier for CDP-X and CDP-Y values, overrides scalar factor obtained from trace header.
+            external_id: External id of the file
 
         Returns:
             EditFileResponse: File information including file id, name, path and crs.
@@ -386,7 +406,11 @@ class FileAPI(API):
         xline_offset_wrapped = None if xline_offset == None else wrappers.Int32Value(value=xline_offset)
         cdp_x_offset_wrapped = None if cdp_x_offset == None else wrappers.Int32Value(value=cdp_x_offset)
         cdp_y_offset_wrapped = None if cdp_y_offset == None else wrappers.Int32Value(value=cdp_y_offset)
+        source_group_scalar_override = (
+            None if source_group_scalar_override == None else wrappers.FloatValue(value=source_group_scalar_override)
+        )
         crs_wrapped = None if crs == None else CRS(crs=crs)
+        external_id = None if external_id == None else ExternalId(external_id=external_id)
         request = EditFileRequest(
             file=file,
             path=bucket,
@@ -397,9 +421,12 @@ class FileAPI(API):
             crossline_offset=xline_offset_wrapped,
             cdp_x_offset=cdp_x_offset_wrapped,
             cdp_y_offset=cdp_y_offset_wrapped,
+            source_group_scalar_override=source_group_scalar_override,
+            external_id=external_id,
         )
         return self.ingestion.EditFile(request=request, metadata=self.metadata)
 
+    @deprecation.deprecated(deprecated_in="0.2.63", details="Multitenant file sharing is not supported anymore")
     def grant_access(
         self,
         file_id: Optional[str] = None,
@@ -421,6 +448,7 @@ class FileAPI(API):
         request = EditFileAccessRequest(file=file, project=project, add=True)
         self.ingestion.EditFileAccess(request=request, metadata=self.metadata)
 
+    @deprecation.deprecated(deprecated_in="0.2.63", details="Multitenant file sharing is not supported anymore")
     def revoke_access(
         self,
         file_id: Optional[str] = None,
