@@ -9,11 +9,7 @@ from google.protobuf import wrappers_pb2 as wrappers
 if not os.getenv("READ_THE_DOCS"):
 
     from cognite.seismic.data_classes.surface_point_list import SurfacePointList
-    from cognite.seismic.protos.query_service_messages_pb2 import (
-        GeometryTimeSliceQueryRequest,
-        Horizon,
-        LineTimeSliceQueryRequest,
-    )
+    from cognite.seismic.protos.query_service_messages_pb2 import GeometryTimeSliceQueryRequest, Horizon
     from cognite.seismic.protos.types_pb2 import CRS, GeoJson, Geometry, LineBasedRectangle, PositionQuery, Wkt
 
 
@@ -55,21 +51,7 @@ class TimeSliceAPI(API):
         Returns:
             A slice of trace data
         """
-        file = self.identify(file_id, file_name)
-        top_left = PositionQuery(iline=top_left_inline, xline=top_left_xline)
-        bottom_right = PositionQuery(iline=bottom_right_inline, xline=bottom_right_xline)
-        rectangle = LineBasedRectangle(top_left=top_left, bottom_right=bottom_right)
-
-        if z is not None:
-            request = LineTimeSliceQueryRequest(file=file, rectangle=rectangle, constant=z)
-        else:
-            flat_horizon = [index for inline_horizon in horizon for index in inline_horizon]
-            request = LineTimeSliceQueryRequest(file=file, rectangle=rectangle, horizon=Horizon(z_values=flat_horizon))
-
-        def get_stream():
-            return self.query.GetTimeSliceByLines(request, metadata=self.metadata)
-
-        return SurfacePointList(get_stream)
+        raise Exception("get_time_slice_by_lines has been removed, use slab api instead: client.slab.get(..)")
 
     def get_time_slice_by_geometry(
         self,
