@@ -163,4 +163,4 @@ class CogniteSeismicClient:
         self.partition = PartitionAPI(self.seismicstub, self.ingestion, self.metadata)
         self.seismics = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
         self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self.metadata, self)
